@@ -6,6 +6,7 @@
 #include <libbonoboui.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomeui/gnome-ui-init.h>
+#include <libgnome/gnome-program.h>
 
 #include "gbf-i18n.h"
 #include "gbf-backend.h"
@@ -112,6 +113,25 @@ open_cb (GtkWidget *widget,
 	gtk_widget_show (file_sel);
 }
 
+static void
+show_packages (GbfProject* proj)
+{
+	GList* modules = gbf_project_get_config_modules(proj, NULL);
+	GList* module;
+	for (module = modules; module != NULL; module = g_list_next (module))
+	{
+		GList* packages = gbf_project_get_config_packages (proj, module->data, NULL);
+		GList* package;
+		printf ("%s\n", (gchar*)module->data);
+		for (package = packages; package != NULL; package = g_list_next (package))
+		{
+			printf ("\t%s\n", (gchar*)package->data);
+		}
+		g_list_foreach (packages, (GFunc)g_free, NULL);
+	}
+	g_list_foreach (modules, (GFunc)g_free, NULL);
+}
+
 static void
 open_project (GtkWidget *widget,
 	      gpointer   user_data)
@@ -170,6 +190,8 @@ open_project (GtkWidget *widget,
 	gbf_project_load (proj, dirname, NULL);
 	g_free (dirname);
 	
+	show_packages (proj);
+	
 	g_object_set (G_OBJECT (model), "project", proj, NULL);
 }
 
@@ -281,9 +303,13 @@ create_window (void)
 int
 main (int argc, char *argv[])
 {
+    GOptionContext *option_context;
+    
+    option_context = g_option_context_new ("");
+    
 	gnome_program_init ("test-controls", VERSION, LIBGNOMEUI_MODULE, 
-			    argc, argv, GNOME_PARAM_POPT_TABLE, 
-			    bonobo_activation_popt_options, NULL);
+			    argc, argv, GNOME_PARAM_GOPTION_CONTEXT, option_context,
+			    GNOME_PARAM_NONE);
 
 	if (!bonobo_init (&argc, argv))
 		g_error (_("Can't initialize bonobo!"));
